# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.ui as windows_ui

Self = typing.TypeVar('Self')

@typing.final
class ToastOcclusionManagerPreview_Static(type):
    def set_toast_window_margin(cls, app_window_id: windows_ui.WindowId, margin: winrt.system.Double, /) -> None: ...

@typing.final
class ToastOcclusionManagerPreview(winrt.system.Object, metaclass=ToastOcclusionManagerPreview_Static):
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_ui_notifications_preview

__all__ = [
    "ToastOcclusionManagerPreview",
]

ToastOcclusionManagerPreview = _winrt_windows_ui_notifications_preview.ToastOcclusionManagerPreview
